@@ -264,7 +264,8 @@ export class Global {
         }
 
         // Always create a new metadata tracker
-        this._metadata = new OptumiMetadataTracker(this._tracker)
+        // TODO:JJ:NOW The user is not yet null, but the user is logged out, so initializing a new metadata tracker causes problems
+        this._metadata = new OptumiMetadataTracker(this._tracker, user == null)
 
         setTimeout(() => {
             Global._user = user;
