@@ -15,13 +15,22 @@ import { Header, SubHeader } from '../core';
 
 interface IProps {
 	sx?: SxProps<Theme>
-	openUserDialogTo?: (page: number) => Promise<void> // This is somewhat spaghetti code-y, maybe think about revising
 }
 
-interface IState {}
+interface IState {
+	activeSessionCount: number
+	activeJobCount: number
+	finishedSessionCount: number
+	finishedJobCount: number
+}
 
 // Defaults for this component
-const DefaultState: IState = {}
+const DefaultState: IState = {
+	activeSessionCount: 0,
+	activeJobCount: 0,
+	finishedSessionCount: 0,
+	finishedJobCount: 0,
+}
 
 export class MonitorPage extends React.Component<IProps, IState> {
 	state = DefaultState;
@@ -38,7 +47,7 @@ export class MonitorPage extends React.Component<IProps, IState> {
 		});
 		return sorted.map(value => (
 				<DIV key={value.uuid} sx={{padding: '6px 0px 6px 6px'}}>
-					{value.getComponent(this.props.openUserDialogTo)}
+					{value.getComponent()}
 				</DIV>
 			)
 		);
@@ -56,7 +65,7 @@ export class MonitorPage extends React.Component<IProps, IState> {
 		});
 		return sorted.map(value => (
 				<DIV key={value.uuid} sx={{padding: '6px 0px 6px 6px'}}>
-					{value.getComponent(this.props.openUserDialogTo)}
+					{value.getComponent()}
 				</DIV>
 			)
 		);
@@ -70,7 +79,7 @@ export class MonitorPage extends React.Component<IProps, IState> {
 			<DIV sx={Object.assign({overflowY: 'auto'}, this.props.sx)}>
 				<DIV sx={{padding: '6px'}}>
 					<Header title="Active" />
-					{appTracker.activeSessions.length != 0 ? (
+					{this.state.activeSessionCount != 0 ? (
 						<>
 							<SubHeader title="Sessions" />
 							{this.generateActive(appTracker.activeSessions)}
@@ -88,7 +97,7 @@ export class MonitorPage extends React.Component<IProps, IState> {
 							</DIV>
 						</DIV>
 					)}
-					{appTracker.activeJobs.length != 0 ? (
+					{this.state.activeJobCount != 0 ? (
 						<>
 							<SubHeader title="Jobs" grey />
 							{this.generateActive(appTracker.activeJobs)}
@@ -109,7 +118,7 @@ export class MonitorPage extends React.Component<IProps, IState> {
 				</DIV>
 				<DIV sx={{padding: '6px'}}>
 					<Header title="Finished" />
-					{appTracker.finishedSessions.length != 0 ? (
+					{this.state.finishedSessionCount != 0 ? (
 						<>
 							<SubHeader title="Sessions" grey />
 							{this.generateFinished(appTracker.finishedSessions)}
@@ -127,7 +136,7 @@ export class MonitorPage extends React.Component<IProps, IState> {
 							</DIV>
 						</DIV>
 					)}
-					{appTracker.finishedJobs.length != 0 ? (
+					{this.state.finishedJobCount != 0 ? (
 						<>
 							<SubHeader title="Jobs" grey />
 							{this.generateFinished(appTracker.finishedJobs)}
@@ -150,10 +159,18 @@ export class MonitorPage extends React.Component<IProps, IState> {
 		);
 	}
 
-	private handleAppChange = () => { this.forceUpdate() }
+	private handleAppChange = () => {
+		this.setState({
+			activeSessionCount: Global.user?.appTracker?.activeSessions?.length || 0,
+			activeJobCount: Global.user?.appTracker?.activeJobs?.length || 0,
+			finishedSessionCount: Global.user?.appTracker?.finishedSessions?.length || 0,
+			finishedJobCount: Global.user?.appTracker?.finishedJobs?.length || 0,
+		})
+	}
 
 	// Will be called automatically when the component is mounted
 	public componentDidMount = () => {
+		this.handleAppChange()
 		Global.user.appTracker.appsChanged.connect(this.handleAppChange);
 	}
 
