@@ -147,7 +147,7 @@ export class OauthLogin extends React.Component<IProps, IState> {
 			</Container>
 			<Container style={{textAlign: 'center'}} maxWidth="xs">
 				<DIV sx={{color: this.state.loginFailed ? 'error.main' : 'text.secondary'}}>
-					{this.state.showLoginHint && (
+					{this.state.showLoginHint && this.state.progress == 'Logging in...' && (
 						<DIV>
 							<br />
 							{"You will be directed to a new browser tab in a moment. If a tab doesn't open, check that your browser is not blocking popups and click "}
@@ -292,12 +292,12 @@ export class OauthLogin extends React.Component<IProps, IState> {
 		if (this.state.progress == 'Logging in...' && new Date().getTime() - this.lastLoginAttempt.getTime() > 600000) {
 			this.safeSetState({ loginFailed: true, loginFailedMessage: "Timed out", waiting: false, showLoginHint: false });
 		}
-		if (first && (new Date().getTime() - this.lastLoginAttempt.getTime() > 5000)) {
-			this.newTab = window.open(window.location.origin + '/optumi/oauth-login')
+		if (first) {
 			if(!this.newTab || this.newTab.closed || typeof this.newTab.closed=='undefined')  {
+				this.newTab = window.open(window.location.origin + '/optumi/oauth-login')
 				this.setState({ showLoginHint: true });
-				this.newTab = null;
-				return;
+			} else {
+				this.newTab.focus()
 			}
 			this.lastLoginAttempt = new Date();
 			this.safeSetState({ progress: 'Logging in...', waiting: true, loginFailed: false, loginFailedMessage: ""});
