@@ -8,21 +8,21 @@
 import * as React from 'react';
 import { DIV, Global } from '../Global';
 
-import { SxProps, Theme } from '@mui/system';
-import { LinearProgress, Chip } from '@mui/material';
+import { alpha, darken, lighten, SxProps, Theme } from '@mui/system';
+import { Chip, CircularProgress } from '@mui/material';
 import { withStyles } from '@mui/styles';
 import { Colors } from '../Colors';
 
 interface IProps {
     id?: string
-    label: string
+    label?: string
     color?: string
-    solid?: boolean
     showLoading?: boolean
     percentLoaded?: number
     icon? : JSX.Element;
     onMouseOver?: (event: React.MouseEvent<HTMLDivElement, MouseEvent>) => void
     onMouseOut?: (event: React.MouseEvent<HTMLDivElement, MouseEvent>) => void
+    onClick?: () => void
     sx?: SxProps<Theme>
 }
 
@@ -31,18 +31,21 @@ interface IState {}
 const progressBorderSize: number = 1
 
 export class Tag extends React.Component<IProps, IState> {
-
-    // Do some extra work to avoid creating new styles every time this component renders
-    PreviousStyledChip: any = null;
-    PreviousStyledLinearProgress: any = null;
-
     StyledChip: any;
-    StyledLinearProgress: any;
+    StyledCircularProgress: any;
 
     public constructor(props: IProps) {
         super(props);
         this.StyledChip = this.getStyledChip();
-        this.StyledLinearProgress = this.getStyledLinearProgress();
+        this.StyledCircularProgress = this.getStyledCircularProgress();
+    }
+
+    private getStyledCircularProgress = () => {
+        return withStyles({
+            root: {
+                color: Global.themeManager == undefined || Global.themeManager.isLight(Global.themeManager.theme) ? darken(this.props.color || Colors.CHIP_GREY, 0.35) : lighten(this.props.color || Colors.CHIP_GREY, 0.35),
+            },
+        }) (CircularProgress);
     }
 
     private getStyledChip = () => {
@@ -52,34 +55,20 @@ export class Tag extends React.Component<IProps, IState> {
                 bottom: '0px',
                 margin: `${progressBorderSize}px`,
                 height: '18px',
-                backgroundColor: this.props.solid ? (this.props.color || Colors.DISABLED) : 'var(--jp-layout-color2)',
-                backgroundImage: 'linear-gradient(rgba(255, 255, 255, 0.05), rgba(255, 255, 255, 0.05))', // This is to match the card color in darkmode
+                backgroundColor: alpha(this.props.color || Colors.CHIP_GREY, 0.25),
                 fontSize: 'var(--jp-ui-font-size1)',
-                color: this.props.solid ? '#ffffff' : '',
+                color: Global.themeManager == undefined || Global.themeManager.isLight(Global.themeManager.theme) ? darken(this.props.color || Colors.CHIP_GREY, 0.35) : lighten(this.props.color || Colors.CHIP_GREY, 0.35),
+                // fontWeight: 'bold',
             },
             label: {
                 overflow: 'visible',
-            }
+            },
+            icon: {
+                fontSize: '14px !important',
+            },
         }) (Chip);
     }
 
-    private getStyledLinearProgress = () => {
-        return withStyles({
-            root: {
-                position: 'absolute',
-                bottom: '0px',
-                height: `${18 + (2 * progressBorderSize)}px`,
-                borderRadius: `${(18 + (2 * progressBorderSize)) / 2}px`,
-            },
-            barColorPrimary: {
-                backgroundColor: this.props.color || Colors.PRIMARY,
-            },
-            colorPrimary: {
-                backgroundColor: Colors.DISABLED,
-            },
-        }) (LinearProgress);
-    }
-
     private handleMouseOver = (event: React.MouseEvent<HTMLDivElement, MouseEvent>) => {
         if (this.props.onMouseOver) this.props.onMouseOver(event);
     }
@@ -90,9 +79,11 @@ export class Tag extends React.Component<IProps, IState> {
 
     public render = (): JSX.Element => {
         if (Global.shouldLogOnRender) console.log('ComponentRender (' + new Date().getSeconds() + ')');
+        const fontSize = getComputedStyle(document.documentElement).getPropertyValue('--jp-ui-font-size1').trim()
+        const fontFamily = getComputedStyle(document.documentElement).getPropertyValue('--jp-ui-font-family').trim()
         return (
             <>
-                {this.props.label != "" && this.props.label != undefined &&
+                {((this.props.label != "" && this.props.label != undefined) || (this.props.icon != undefined)) &&
                     <DIV
                         sx={Object.assign({
                             position: 'relative',
@@ -101,28 +92,37 @@ export class Tag extends React.Component<IProps, IState> {
                         onMouseOver={this.handleMouseOver}
                         onMouseOut={this.handleMouseOut}
                     >
-                        {this.props.showLoading && (
-                            this.props.percentLoaded === undefined ? (
-                                <this.StyledLinearProgress
-                                    sx={{width: (Global.getStringWidth(this.props.label, '13px Roboto, Helvetica, Arial, sans-serif') + 14 + (2 * progressBorderSize)) + 'px'}}
-                                />
-                            ) : (
-                                <this.StyledLinearProgress
-                                    sx={{width: (Global.getStringWidth(this.props.label, '13px Roboto, Helvetica, Arial, sans-serif') + 14 + (2 * progressBorderSize)) + 'px'}}
-                                    variant='determinate'
-                                    value={this.props.percentLoaded * 100}
-                                />
-                            )
-                        )}
                         <this.StyledChip
+                            onClick={this.props.onClick}
                             key={this.props.label + this.props.color + this.props.icon}
                             id={this.props.id}
                             size='small'
                             label={this.props.label}
-                            icon={this.props.icon}
+                            icon={this.props.showLoading ? (
+                                <DIV sx={{height: '16px'}}>
+                                    {
+                                        this.props.percentLoaded === undefined ? (
+                                            <this.StyledCircularProgress 
+                                                size='14px'
+                                                thickness={6}
+                                            />
+                                        ) : (
+                                            <this.StyledCircularProgress
+                                                size='14px'
+                                                thickness={6}
+                                                variant='determinate'
+                                                value={this.props.percentLoaded * 100}
+                                            />
+                                        )
+                                    }
+                                </DIV>
+                            ) : (
+                                <DIV sx={{height: '14px'}}>
+                                    {this.props.icon}
+                                </DIV>
+                            )}
                             sx={{
-                                border: !this.props.showLoading ? '1px solid ' + (this.props.color || Colors.DISABLED) : '',
-                                width: ((Global.getStringWidth(this.props.label, '13px Roboto, Helvetica, Arial, sans-serif') + 14) + (this.props.icon ? 14 : 0)) + 'px',
+                                width: (this.props.label != "" && this.props.label != undefined) ? ((Global.getStringWidth(this.props.label, fontSize + " " + fontFamily) + 14) + (this.props.showLoading || this.props.icon ? 14 : 0)) + 'px' : '18px',
                             }}
                         />
                     </DIV>
@@ -131,6 +131,20 @@ export class Tag extends React.Component<IProps, IState> {
         )
     }
 
+    private handleThemeChange = () => {
+        this.StyledChip = this.getStyledChip();
+        this.StyledCircularProgress = this.getStyledCircularProgress();
+        this.forceUpdate()
+    }
+
+    public componentDidMount = () => {
+        Global.themeManager.themeChanged.connect(this.handleThemeChange)
+    }
+
+    public componentWillUnmount = () => {
+        Global.themeManager.themeChanged.disconnect(this.handleThemeChange)
+    }
+
     public shouldComponentUpdate = (nextProps: IProps, nextState: IState): boolean => {
         try {
             if (JSON.stringify(this.props) != JSON.stringify(nextProps)) return true;
