@@ -11,7 +11,7 @@ import { Global } from '../../Global';
 import { SxProps, Theme } from '@mui/system';
 
 import { TextBox } from '../../core';
-import { DataService } from './dataConnectorBrowser/DataConnectorDirListingItemIcon';
+import { DataService } from './IntegrationBrowser/IntegrationDirListingItemIcon';
 import { BaseConnectorPopup } from '../../core/BaseConnectorPopup';
 
 interface IProps {
@@ -54,7 +54,7 @@ export class AzureBlobStorageConnectorPopup extends React.Component<IProps, ISta
                 header='Connect to an Azure Blob Storage container or blob.'
                 downloadPath=''
                 onClose={this.handleClose}
-                getInfo={() => this.state}
+                getInfo={() => this.state }
                 getContents={(waiting: boolean) => (
                     <>
                         <TextBox<string>
