@@ -68,7 +68,7 @@ export class PreviewLaunchButton extends React.Component<IProps, IState> {
 			if (bypassLimiter || !retrievingPreview) {
 				try {
 					retrievingPreview = true;
-					const app = new App(current.context.path, current.model.toJSON(), config);
+					const app = new App(Global.convertJupyterPathToOptumiPath(current.context.path), JSON.stringify(current.model.toJSON()), config);
 					app.previewNotebook(printRecommendations).then((machines: Machine[]) => {
 						this.safeSetState({
 							machine: machines,
