@@ -6,11 +6,12 @@
 **/
 
 import * as React from 'react'
+import { DIV, Global } from '../../../Global';
+
 import BreadCrumbEllipses from './BreadCrumbEllipses'
 import BreadCrumbHome from './BreadCrumbHome'
 import BreadCrumbItem from './BreadCrumbItem'
 import { FileMetadata } from './FileBrowser'
-import { Global } from '../../../Global';
 
 interface IProps {
     serverRoot: string
@@ -30,12 +31,12 @@ export default class BreadCrumbs extends React.Component<IProps, IState> {
     public render = (): JSX.Element => {
 		if (Global.shouldLogOnRender) console.log('ComponentRender (' + new Date().getSeconds() + ')');
         return (
-            <div className='jp-BreadCrumbs jp-FileBrowser-crumbs'>
+            <DIV className='jp-BreadCrumbs jp-FileBrowser-crumbs'>
                 <BreadCrumbHome serverRoot={this.props.serverRoot} file={this.props.root} onOpen={this.props.onOpen} />
                 {this.props.path.length > 2 && <BreadCrumbEllipses file={this.props.path[this.props.path.length - 3]} onOpen={this.props.onOpen} />}
                 {this.props.path.length > 1 && <BreadCrumbItem file={this.props.path[this.props.path.length - 2]} onOpen={this.props.onOpen} />}
                 {this.props.path.length > 0 && <BreadCrumbItem file={this.props.path[this.props.path.length - 1]} onOpen={this.props.onOpen} />}
-            </div>
+            </DIV>
         )
     }
 }
\ No newline at end of file
