@@ -16,8 +16,10 @@ import { FileMetadata } from './FileBrowser'
 interface IProps {
     filter: string
     files: FileMetadata[]
+    getSelected?: (getSelected: () => FileMetadata[]) => void
     onOpen: (file: FileMetadata) => void
-    getSelected: (getSelected: () => FileMetadata[]) => void
+    onDownload?: (file: FileMetadata) => void
+    onDelete?: (file: FileMetadata) => void
 }
 
 interface IState {
@@ -83,7 +85,7 @@ export default class DirListing extends React.Component<IProps, IState> {
                                 this.safeSetState({selected: 'modified', sorted: 'forward'})
                             }
                         }}
-                        sx={{flex: '0 0 150px'}}
+                        style={{flex: '0 0 150px'}}
                     >
                         <SPAN className='jp-DirListing-headerItemText'>
                             Last Modified
@@ -105,6 +107,8 @@ export default class DirListing extends React.Component<IProps, IState> {
                     onOpen={this.props.onOpen}
                     sort={sort}
                     getSelected={this.props.getSelected}
+                    onDownload={this.props.onDownload}
+                    onDelete={this.props.onDelete}
                 />
             </DIV>
         )
@@ -139,4 +143,4 @@ export default class DirListing extends React.Component<IProps, IState> {
 			}
 		}
 	}
-}
\ No newline at end of file
+}
