@@ -68,7 +68,7 @@ export default class DirListingItem extends React.Component<IProps, IState> {
                     title={fileTitle(file)}
                     style={{padding: hidableIcon ? '8px 12px' : '4px 12px', background : !this.props.selected && this.state.hovered ? 'var(--jp-layout-color2)' : ''}}
                 >
-                    <DirListingItemIcon fileType={file.type} mimetype={file.mimetype} />
+                    <DirListingItemIcon fileType={file.type} mimetype={file.mimetype} extension={file.path.split('.').pop()} />
                     <SPAN className='jp-DirListing-itemText' dangerouslySetInnerHTML={{ __html: html }}/>
                     <SPAN
                         sx={{ opacity: this.state.hovered && hidableIcon ? 0 : 1, }}
