@@ -33,6 +33,7 @@ import { SubscriptionEnded } from './SubscriptionEnded';
 import { CustomerState } from '../../core/CustomerState';
 import { FreeTrialEnded } from './FreeTrialEnded';
 import { EnvironmentVariablePopup } from '../../core/EnvironmentVariablePopup';
+import { ProgramType } from '../../models/OptumiConfig';
 
 // Properties from parent
 interface IAccountPreferencesSubMenuProps {
@@ -119,7 +120,7 @@ export class AccountPreferencesSubMenu extends React.Component<IAccountPreferenc
                                             this.stringToCSVCell(app.annotationOrRunNum),
                                             app.timestamp,
                                             app.getTimeElapsed(),
-                                            app.interactive ? 'N/A' : app.notebook.metadata.papermill.duration,
+                                            app.interactive || app.programType != ProgramType.PYTHON_NOTEBOOK ? 'N/A' : app.program.metadata.papermill.duration,
                                             app.getCost(),
                                             app.getAppMessage(),
                                             machine.name,
@@ -142,14 +143,12 @@ export class AccountPreferencesSubMenu extends React.Component<IAccountPreferenc
 
                                     await new Promise(resolve => setTimeout(resolve, 100));
 
-                                    // const ipynbContent = 'data:text/plain;charset=utf-8,'
-                                    //     + JSON.stringify(app.notebook);
                                     var link = document.createElement("a");
-                                    var blob = new Blob([JSON.stringify(app.notebook)], {
+                                    var blob = new Blob([JSON.stringify(app.program)], {
                                         type: "text/plain;charset=utf-8"
                                     });
                                     link.setAttribute("href", window.URL.createObjectURL(blob));
-                                    link.setAttribute("download", app.uuid + ".ipynb");
+                                    link.setAttribute("download", app.uuid + app.name.split('.').pop());
                                     document.body.appendChild(link); // Required for FF
                                     link.click();
 
