@@ -135,11 +135,11 @@ export class BaseConnectorPopup extends React.Component<IProps, IState> {
             Global.handleResponse(response);
             return response.json();
         }).then((body: any) => {
-            if (body.message) {
-                // This means there was a failure
-                // Show what went wrong
-                this.safeSetState({ waiting: false, addSpinning: false, createSpinning: false, errorMessage: body.message });
-            } else {
+            try {
+                var parsed = JSON.parse(body.message)
+                // TODO:JJ This is a hacky way to figure out if the returned value is a json data connector (meaning this was successful)
+                if (!(parsed.integrationType && parsed.type && parsed.name && parsed.dataService)) throw Error()
+
                 this.safeSetState({ waiting: false, addSpinning: false, createSpinning: false })
                 if (add && !this.nameHasError(this.state.name)) {
                     const tracker = Global.metadata
@@ -153,6 +153,10 @@ export class BaseConnectorPopup extends React.Component<IProps, IState> {
                 }
                 // Success
                 this.handleClose()
+            } catch (err) {
+                // This means there was a failure
+                // Show what went wrong
+                this.safeSetState({ waiting: false, addSpinning: false, createSpinning: false, errorMessage: body.message });
             }
         }, (error: ServerConnection.ResponseError) => {
             console.error(error)
