@@ -6,9 +6,11 @@
 **/
 
 import * as React from 'react';
-import { Global } from '../Global';
-import withStyles, { CSSProperties } from '@material-ui/core/styles/withStyles';
-import { FormControl, FormHelperText, MenuItem, Select } from '@material-ui/core';
+import { DIV, Global, StyledSelect } from '../Global';
+
+import { SxProps, Theme } from '@mui/system';
+import { FormControl, FormHelperText, MenuItem, SelectChangeEvent } from '@mui/material';
+import { withStyles } from '@mui/styles';
 
 const StyledMenuItem = withStyles({
     root: {
@@ -19,12 +21,12 @@ const StyledMenuItem = withStyles({
 }) (MenuItem)
 
 interface IProps {
-    style?: CSSProperties
+    sx?: SxProps<Theme>
     label?: string
     labelWidth?: string
     getValue: () => string
     saveValue: (value: string) => string | void
-    values: {value: string, description: string}[]
+    values: {value: string, description: string, disabled?: boolean}[]
     helperText?: string
     onFocus?: (event: React.FocusEvent<HTMLInputElement>) => void
     onBlur?: (event: React.FocusEvent<HTMLInputElement>) => void
@@ -38,30 +40,14 @@ interface IState {
 export class Dropdown extends React.Component<IProps, IState> {
     private _isMounted = false
 
-    StyledSelect: any
-
     constructor(props: IProps) {
         super(props);
         this.state = {
             value: this.props.getValue(),
         }
-        this.StyledSelect = this.getStyledSelect();
     }
 
-    private getStyledSelect = () => {
-        return withStyles({
-            root: {
-                fontSize: "var(--jp-ui-font-size1)",
-                padding: '3px 3px 3px 6px',
-                textAlign: 'start',
-            },
-            iconOutlined: {
-                right: '0px'
-            }
-        }) (Select)
-    }
-
-    private handleValueChange = (event: React.ChangeEvent<{ value: unknown }>) => {
+    private handleValueChange = (event: SelectChangeEvent<unknown>) => {
         const value = event.target.value as string
         this.safeSetState({value: value})
         this.props.saveValue(value);
@@ -70,46 +56,45 @@ export class Dropdown extends React.Component<IProps, IState> {
     public render = (): JSX.Element => {
         if (Global.shouldLogOnRender) console.log('ComponentRender (' + new Date().getSeconds() + ')');
         return (
-            <div style={Object.assign({
+            <DIV sx={Object.assign({
                 display: 'inline-flex',
                 width: '100%',
                 padding: '6px 0px',
                 // textAlign: 'center',
                 // justifyContent: 'center'
-            }, this.props.style)}>
-                {this.props.label && <div style={{
+            }, this.props.sx)}>
+                {this.props.label && <DIV sx={{
                     minWidth: this.props.labelWidth || '68px',
                     margin: '0px 12px',
                     lineHeight: '24px',
                 }}>
                     {this.props.label}
-                </div>}
+                </DIV>}
                 <FormControl
                     variant='outlined'
-                    style={{width: '100%', margin: '2px 6px', height: this.props.helperText ? '32px' : '20px'}}
+                    sx={{width: '100%', margin: '2px 6px', height: this.props.helperText ? '32px' : '20px'}}
                 >
-                    <this.StyledSelect
+                    <StyledSelect
                         value={this.state.value}
-                        variant='outlined'
                         onChange={this.handleValueChange}
                         SelectDisplayProps={{style: {padding: '1px 20px 1px 6px'}}}
                         MenuProps={{MenuListProps: {style: {paddingTop: '6px', paddingBottom: '6px'}}}}
-                        style={{width: '100%'}}
+                        sx={{width: '100%'}}
                         disabled={this.props.disabled}
                     >
                         {this.props.values.map(value =>
-                            <StyledMenuItem key={value.value} value={value.value}>
+                            <StyledMenuItem key={value.value} value={value.value} disabled={value.disabled}>
                                 {value.value + (value.description ? (': ' + value.description) : '')}
                             </StyledMenuItem>
                         )}
-                    </this.StyledSelect>
+                    </StyledSelect>
                     {this.props.helperText && 
-                        <FormHelperText style={{fontSize: '10px', lineHeight: '10px', margin: '4px 6px', whiteSpace: 'nowrap'}}>
+                        <FormHelperText sx={{fontSize: '10px', lineHeight: '10px', margin: '4px 6px', whiteSpace: 'nowrap'}}>
                             {this.props.helperText}
                         </FormHelperText>
                     }
                 </FormControl>
-            </div>
+            </DIV>
         )
     }
 
