@@ -14,7 +14,6 @@ import { OpenInNew } from '@mui/icons-material';
 
 import { OptumiConfig } from '../models/OptumiConfig';
 import { Dropdown, Switch } from '.';
-import { Page } from '../components/UserDialog';
 
 
 interface IProps {
@@ -22,7 +21,6 @@ interface IProps {
     getValue: () => OptumiConfig
     saveValue: (config: OptumiConfig) => void
     disabled?: boolean
-	openUserDialogTo?: (page: number) => Promise<void> // This is somewhat spaghetti code-y, maybe think about revising
     handleClose?: () => void
 }
 
@@ -103,14 +101,14 @@ export class NotificationContent extends React.Component<IProps, IState> {
                 
             </DIV>
             {(disabled && !this.props.disabled) && (
-                <DIV sx={{display: 'inline-flex', width: '100%',margin: '12px 36px'}}>
+                <DIV sx={{display: 'inline-flex', width: 'calc(100% - 72px)',margin: '12px 36px'}}>
                     <DIV sx={{margin: 'auto 0px', fontStyle: 'italic'}}>
                         Notifications can be enabled in settings
                     </DIV>
                     <IconButton
                         size='large'
                         onClick={() => {
-                            if (this.props.openUserDialogTo) this.props.openUserDialogTo(Page.PREFERENCES);
+                            Global.followLink(Global.Target.SettingsPopup.PreferencesTab)
                             if (this.props.handleClose) this.props.handleClose();
                         }}
                         sx={{
