@@ -42,7 +42,7 @@ export class PhoneTextBox extends React.Component<IProps, IState> {
 
     constructor(props: IProps) {
         super(props);
-        const value: any = this.props.getValue();
+        const value: any = this.props.getValue().replace('+', '');
         this.state = {
             value: value == '' ? '1' : value,
             invalidTextMessage: '',
@@ -66,9 +66,9 @@ export class PhoneTextBox extends React.Component<IProps, IState> {
         } else {
             try {
                 const phoneUtil = libphonenumber.PhoneNumberUtil.getInstance();
-                if (phoneUtil.isValidNumber(phoneUtil.parse(value, 'US'))) {
+                if (phoneUtil.isValidNumber(phoneUtil.parse('+' + value, 'US'))) {
                     this.safeSetState({editing: false, value: value})
-                    this.props.saveValue(value)
+                    this.props.saveValue('+' + value)
                 } else {
                     invalid = true;
                 }
@@ -128,10 +128,12 @@ export class PhoneTextBox extends React.Component<IProps, IState> {
                         onChange={this.handleChange}
                         preferredCountries={['us']}
                         containerStyle={{margin: 'auto 0px auto 6px'}}
-                        inputStyle={{height:'20.25px', width: '100%'}}
+                        inputStyle={{height:'20.25px', width: '100%', background: 'var(--jp-layout-color1)', color: 'var(--jp-ui-font-color0)'}}
+                        buttonStyle={{height: '20.25px', background: 'var(--jp-layout-color1)', color: 'var(--jp-ui-font-color0)'}}
+                        dropdownStyle={{background: 'var(--jp-layout-color1)', color: 'var(--jp-ui-font-color0)'}}
+                        searchStyle={{background: 'var(--jp-layout-color1)', color: 'var(--jp-ui-font-color0)'}}
                         onFocus={this.handleFocus}
                         onBlur={this.handleBlur}
-                        buttonStyle={{height: '20.25px'}}
                         isValid={this.state.invalidTextMessage == ''}
                     />
                 {/* </ExtraInfo> */}
