@@ -6,8 +6,9 @@
 **/
 
 import * as React from 'react'
-import { Global } from '../Global'
-import { Divider, lighten } from '@material-ui/core'
+import { DIV, Global } from '../Global'
+
+import { Divider, lighten } from '@mui/material'
 
 interface IProps {
     orientation?: 'vertical' | 'horizontal'
@@ -23,14 +24,14 @@ export class ShadowedDivider extends React.Component<IProps, IState> {
         const lightColor = this.isLightMode ? lighten(darkColor, 2/3) : 'rgba(255, 255, 255, 0.12)'
         return this.props.orientation === undefined || this.props.orientation === 'horizontal' ? (
             <>
-                <Divider variant='fullWidth' style={{backgroundColor: darkColor}} />
-                <Divider variant='fullWidth' style={{backgroundColor: lightColor}} />
+                <Divider variant='fullWidth' sx={{backgroundColor: darkColor}} />
+                <Divider variant='fullWidth' sx={{backgroundColor: lightColor}} />
             </>
         ) : this.props.orientation === 'vertical' && (
-            <div style={{display: 'flex', height: '100%'}}>
-                <Divider orientation='vertical' variant='fullWidth' style={{backgroundColor: darkColor}} />
-                <Divider orientation='vertical' variant='fullWidth' style={{backgroundColor: lightColor}} />
-            </div>
+            <DIV sx={{display: 'flex', height: '100%'}}>
+                <Divider orientation='vertical' variant='fullWidth' sx={{backgroundColor: darkColor}} />
+                <Divider orientation='vertical' variant='fullWidth' sx={{backgroundColor: lightColor}} />
+            </DIV>
         )
     }
 
@@ -43,4 +44,4 @@ export class ShadowedDivider extends React.Component<IProps, IState> {
     public componentWillUnmount = () => {
         Global.themeManager.themeChanged.disconnect(this.handleThemeChange)
     }
-}
\ No newline at end of file
+}
