@@ -11,6 +11,7 @@ import { DIV, Global } from '../Global';
 import {
     Button,
     Checkbox,
+    CircularProgress,
     Dialog,
     DialogActions,
     DialogContent,
@@ -37,20 +38,25 @@ interface IProps {
     open: boolean,
     headerText?: string
     bodyText?: string
+    bodyContent?: JSX.Element
     preventText?: string
     cancel?: {
         text: string
-        onCancel: (prevent: boolean) => void
+        onCancel?: (prevent: boolean) => void
+        onCancelAsync?: (prevent: boolean) => Promise<any>
     }
     continue: {
         text: string
-        onContinue: (prevent: boolean) => void
+        onContinue?: (prevent: boolean) => void
+        onContinueAsync?: (prevent: boolean) => Promise<any>
         color: 'primary' | 'secondary' | 'error' | 'success' | 'warning' | 'info'
     }
 }
 
 interface IState {
     prevent: boolean
+    cancelWaiting: boolean
+    continueWaiting: boolean
 }
 
 export default class WarningPopup extends React.Component<IProps, IState> {
@@ -62,6 +68,8 @@ export default class WarningPopup extends React.Component<IProps, IState> {
         super(props)
         this.state = {
             prevent: false,
+            cancelWaiting: false,
+            continueWaiting: false,
         }
         this.ContinueButton = withStyles((theme: Theme) => {
             const paletteColor = (() => {
@@ -94,7 +102,6 @@ export default class WarningPopup extends React.Component<IProps, IState> {
 		if (Global.shouldLogOnRender) console.log('ComponentRender (' + new Date().getSeconds() + ')');
         return (
             <StyledDialog
-                onClose={(event: object, reason: string) => void 0}
                 open={this.props.open}
             >
                 {this.props.headerText &&
@@ -117,6 +124,11 @@ export default class WarningPopup extends React.Component<IProps, IState> {
                             {this.props.bodyText}
                         </DialogContent>
                     }
+                    {this.props.bodyContent &&
+                        <DialogContent sx={{padding: '6px 18px', whiteSpace: 'pre-wrap'}}>
+                            {this.props.bodyContent}
+                        </DialogContent>
+                    }
                     <DialogActions sx={{padding: '12px 6px 6px 6px'}}>
                         {this.props.preventText &&
                             <>
@@ -134,19 +146,42 @@ export default class WarningPopup extends React.Component<IProps, IState> {
                         {this.props.cancel &&
                             <Button
                                 variant='contained'
-                                onClick={() => {
-                                    this.safeSetState({prevent: false})
-                                    this.props.cancel.onCancel(this.state.prevent)
+                                color='secondary'
+                                sx={{opacity: this.state.continueWaiting ? '0' : '1', transition: 'all 225ms', pointerEvents: this.state.continueWaiting ? 'none' : 'auto'}}    // Hide this button if the other one is spinning
+                                disabled={this.state.cancelWaiting}
+                                onClick={async () => {
+                                    setTimeout(() => this.safeSetState({prevent: false, cancelWaiting: true }), 250)
+                                    if (this.props.cancel.onCancelAsync) {
+                                        await this.props.cancel.onCancelAsync(this.state.prevent)
+                                    } else {
+                                        this.props.cancel.onCancel(this.state.prevent)
+                                    }
+                                    setTimeout(() => this.safeSetState({ cancelWaiting: false }), 250)
                                 }}>
-                                {this.props.cancel.text}
+                                {this.state.cancelWaiting && (<CircularProgress size='1.75em'/>)}
+                                <DIV sx={{paddingLeft: this.state.cancelWaiting ? '12px' : ''}}>
+                                    {this.props.cancel.text}
+                                </DIV>
                             </Button>
                         }
                         <this.ContinueButton
                             variant='contained'
-                            onClick={() => this.props.continue.onContinue(this.state.prevent)}
-                            sx={{marginLeft: '18px'}}
+                            sx={{marginLeft: '18px', opacity: this.state.cancelWaiting ? '0' : '1', transition: 'all 225ms', pointerEvents: this.state.continueWaiting ? 'none' : 'auto'}}    // Hide this button if the other one is spinning
+                            disabled={this.state.continueWaiting}
+                            onClick={async () => {
+                                setTimeout(() => this.safeSetState({ continueWaiting: true }), 250)
+                                if (this.props.continue.onContinueAsync) {
+                                    await this.props.continue.onContinueAsync(this.state.prevent)
+                                } else {
+                                    this.props.continue.onContinue(this.state.prevent)
+                                }
+                                setTimeout(() => this.safeSetState({ continueWaiting: false }), 250)
+                            }}
                         >
-                            {this.props.continue.text}
+                            {this.state.continueWaiting && (<CircularProgress size='1.75em'/>)}
+                            <DIV sx={{paddingLeft: this.state.continueWaiting ? '12px' : ''}}>
+                                {this.props.continue.text}
+                            </DIV>
                         </this.ContinueButton>
                     </DialogActions>
                 </DIV>
