@@ -6,9 +6,10 @@
 **/
 
 import * as React from 'react'
+import { DIV, Global } from '../../Global';
+
 import Editor from './Editor'
 import Markdown from './Markdown'
-import { Global } from '../../Global';
 
 interface IProps {
     cell: any
@@ -34,9 +35,9 @@ export default class InputArea extends React.Component<IProps, IState> {
             scrollID = 'scrollHere'
         }
         return (
-            <div id={scrollID} className='p-Widget lm-Widget jp-Cell-inputWrapper'>
-                <div className='p-Widget lm-Widget jp-InputArea jp-Cell-inputArea'>
-                    <div className='p-Widget lm-Widget jp-InputPrompt jp-InputArea-prompt'>
+            <DIV id={scrollID} className='p-Widget lm-Widget jp-Cell-inputWrapper'>
+                <DIV className='p-Widget lm-Widget jp-InputArea jp-Cell-inputArea'>
+                    <DIV className='p-Widget lm-Widget jp-InputPrompt jp-InputArea-prompt'>
                     {this.props.cell.cell_type === 'code' ? (
                         <>
                             {this.props.cell.execution_count !== undefined && `[${exec_count}]:`}
@@ -46,7 +47,7 @@ export default class InputArea extends React.Component<IProps, IState> {
                     ) : (
                         <></>
                     )}
-                    </div>
+                    </DIV>
                     {this.props.cell.cell_type === 'code' ? (
                         <Editor cell={this.props.cell} metadata={this.props.metadata} renderInColor={this.props.renderInColor} />
                     ) : this.props.cell.cell_type === 'markdown' ? (
@@ -54,8 +55,8 @@ export default class InputArea extends React.Component<IProps, IState> {
                     ) : (
                         <></>
                     )}
-                </div>
-            </div>
+                </DIV>
+            </DIV>
         )
     }
 
