@@ -5,7 +5,7 @@
 **  To receive a copy of the licensing terms please write to contact@optumi.com or visit us at http://www.optumi.com.
 **/
 
-export class AWSRegion {
+class AWSRegion {
     public region: string
     public description: string
 
