@@ -8,6 +8,7 @@
 import { Update } from './Update';
 import { Machine } from './machine/Machine';
 import { FileMetadata } from '../components/deploy/fileBrowser/FileBrowser';
+import { ISignal, Signal } from '@lumino/signaling';
 
 export enum Status {
 	INITIALIZING,
@@ -16,6 +17,12 @@ export enum Status {
 }
 
 export class Module {
+	private _changed = new Signal<this, Module>(this);
+
+	get changed(): ISignal<this, Module> {
+		return this._changed;
+	}
+
 	get sessionReady(): boolean {
 		return this._sessionToken != null;
 	}
@@ -124,12 +131,14 @@ export class Module {
 				this.updateNotebook(JSON.parse(notebook));
 				const n = body.patchesmod[0]
 				if (!isNaN(parseFloat(n)) && isFinite(n)) this._lastPatch = +n;
+				updated = true
 			} catch (err) {
 				console.warn('Unable to update notebook ' + notebook);
 			}
 		}
 		if (body.patches != null) {
 			// Apply any patch(es)
+			if (body.patches.length > 0) updated = true;
 			for (var i = 0; i < body.patches.length; i++) {
 				const patch = body.patches[i];
 				try {
@@ -184,6 +193,9 @@ export class Module {
 				}
 			}
 		}
+
+		if (updated) this._changed.emit(this)
+
 		return updated;
 	}
 }
