@@ -15,7 +15,7 @@ import { ISignal, Signal } from '@lumino/signaling';
 import { ProgressMessage } from '../ProgressMessage';
 import { Module, Status } from '../Module';
 import { AppTracker } from './AppTracker';
-import { OptumiConfig } from '../OptumiConfig';
+import { guessFromExtension, OptumiConfig, ProgramType } from '../OptumiConfig';
 import { FileUploadConfig } from '../FileUploadConfig';
 import { Machine, NoMachine } from '../machine/Machine';
 import { Update } from '../Update';
@@ -45,15 +45,17 @@ export class App {
 
 	public globalChangedTrigger: () => void
 
-	private _notebook: any;
+	private _program: any;
 	private _config: OptumiConfig;
 
 	private applyPatch = (patch: any) => {
-		applyPatch(this._notebook, patch);
+		var json = JSON.parse(this._program)
+		applyPatch(json, patch);
+		this._program = JSON.stringify(json)
 	}
 
 	private updateNotebook = (notebook: any) => {
-		this._notebook = notebook;
+		this._program = JSON.stringify(notebook);
 	}
 
 	private _path: string;
@@ -72,7 +74,7 @@ export class App {
 	constructor(path: string, notebook: any = {}, config: OptumiConfig = new OptumiConfig(), uuid: string = "",
 		initializing: Update[] = [], preparing: Update[] = [], running: Update[] = [], files: FileMetadata[] = [], timestamp = new Date(), runNum: number = 0) {		
 
-		this._notebook = notebook;
+		this._program = notebook;
 		this._config = config.copy();
 
 		this._path = path;
@@ -144,7 +146,7 @@ export class App {
 			}
 		}
 
-		var app: App = new App(appMap.name, JSON.parse(appMap.notebook), new OptumiConfig(JSON.parse(appMap.nbConfig)), appMap.uuid, initializing, preparing, running, inputFiles, new Date(appMap.timestamp), appMap.runNum);
+		var app: App = new App(appMap.name, appMap.notebook, new OptumiConfig(JSON.parse(appMap.nbConfig)), appMap.uuid, initializing, preparing, running, inputFiles, new Date(appMap.timestamp), appMap.runNum);
 		// Add modules
 		for (let module of appMap.modules) {
             const output: Update[] = [];
@@ -207,6 +209,7 @@ export class App {
 
 			var mod: Module = new Module(module.uuid, module.machine ? Machine.parse(module.machine) : null, module.token, output, updates, outputFiles, monitoring, lastPatch);
 			mod.applyPatch = app.applyPatch;
+			mod.changed.connect(() => { app._changed.emit(app) })
 			app._modules.push(mod);
 		}
 		return app;
@@ -296,31 +299,47 @@ export class App {
 				this._running.addUpdate(update, false);
 			}
 		}
+
+		if (updated) this._changed.emit(this)
+
 		return updated;
 	}
 
-	get notebook(): any {
-		const copy = JSON.parse(JSON.stringify(this._notebook));
-		// JupyterLab combines lines with \n, but we need to combine them with ''
-		for (var cell of copy.cells) {
-			if (cell.outputs) {
-				for (var output of cell.outputs) {
-					if (output.text) {
-						if (Array.isArray(output.text)) {
-							output.text = (output.text as string[]).join('');
-						} else {
-							output.text = output.text.toString()
+	get programType(): ProgramType {		
+		var ret =  this._config.programType || ProgramType.UNKNOWN
+		if (ret == ProgramType.UNKNOWN) ret = guessFromExtension(this._path.split('.').pop())
+		return ret
+	}
+
+	get program(): any {
+		switch (this.programType) {
+			case ProgramType.PYTHON_NOTEBOOK:
+				const copy = JSON.parse(this._program);
+				// JupyterLab combines lines with \n, but we need to combine them with ''
+				for (var cell of copy.cells) {
+					if (cell.outputs) {
+						for (var output of cell.outputs) {
+							if (output.text) {
+								if (Array.isArray(output.text)) {
+									output.text = (output.text as string[]).join('');
+								} else {
+									output.text = output.text.toString()
+								}
+							}
 						}
 					}
 				}
-			}
+				// Let JupyterLab handle the formatting
+				const model = new NotebookModel()
+				model.fromJSON(copy);
+				model.initialize()
+				const formatted = model.toJSON()
+				return formatted
+			case ProgramType.PYTHON_SCRIPT:
+				return this._program;
+			default:
+				return
 		}
-		// Let JupyterLab handle the formatting
-		const model = new NotebookModel()
-		model.fromJSON(copy);
-		model.initialize()
-		const formatted = model.toJSON()
-		return formatted
 	}
 
 	get config(): OptumiConfig {
@@ -355,7 +374,8 @@ export class App {
 	}
 
 	get name(): string {
-		return this._path.split('/').pop().replace('.ipynb', '');
+		const name = this._path.split('/').pop()
+		return name.replace('.' + name.split('.').pop(), '')
 	}
 
 	get annotationOrRunNum(): string {
@@ -486,7 +506,7 @@ export class App {
 				timestamp: this._timestamp.toISOString(),
 				notebook: {
 					path: this._path,
-					content: JSON.stringify(this._notebook),
+					content: this._program,
 				},
 				nbConfig: JSON.stringify(this._config),
 			}),
@@ -554,6 +574,7 @@ export class App {
 						const mod = new Module(body.modules[i]);
 						mod.applyPatch = this.applyPatch
 						mod.updateNotebook = this.updateNotebook
+						mod.changed.connect(() => { this._changed.emit(this) })
 						this._modules.push(mod);
 					}
 					if (body.files) {
@@ -631,7 +652,7 @@ export class App {
 		data.uuid = this._uuid;
 		data.notebook = {
 			path: this._path,
-			content: JSON.stringify(this._notebook),
+			content: this._program,
 		}
 		data.timestamp = this._timestamp.toISOString();
 
