@@ -8,8 +8,9 @@
 import * as React from 'react';
 import { Global } from '../../Global';
 
+import { darken, lighten } from '@mui/system';
 import { IconButton, CircularProgress } from '@mui/material';
-import { Clear as ClearIcon, Check as CheckIcon, Delete as DeleteIcon, Stop as StopIcon } from '@mui/icons-material';
+import { Clear, Check, Delete, Stop, WarningRounded } from '@mui/icons-material';
 
 import { ServerConnection } from '@jupyterlab/services';
 
@@ -24,7 +25,6 @@ import { Colors } from '../../Colors';
 
 interface IProps {
 	app: App,
-	openUserDialogTo?: (page: number) => Promise<void> // This is somewhat spaghetti code-y, maybe think about revising
 }
 
 interface IState {
@@ -66,6 +66,7 @@ export class AppComponent extends React.Component<IProps, IState> {
 			method: 'POST',
 			body: JSON.stringify({
 				workload: this.props.app.uuid,
+				module: this.props.app.modules[0].uuid,
 			}),
 		};
 		ServerConnection.makeRequest(
@@ -110,10 +111,7 @@ export class AppComponent extends React.Component<IProps, IState> {
 	}
 
 	private getStatusColor = (): string => {
-		if (this.props.app.getAppMessage() == 'Closed' || this.props.app.getAppMessage() == 'Terminated') {
-			return Colors.DISABLED;
-		}
-		if (this.props.app.getError()) {
+		if (this.props.app.error) {
 			return Colors.ERROR;
 		} else {
 			const appStatus = this.props.app.getAppStatus();
@@ -125,6 +123,16 @@ export class AppComponent extends React.Component<IProps, IState> {
 		}
 	}
 
+	private getChipColor = (): string => {
+		const message = this.props.app.getAppMessage()
+		if (this.props.app.error) {
+			return Colors.ERROR
+		} else if (message == 'Completed') {
+			return Colors.SUCCESS
+		}
+		return undefined
+	}
+
 	public render = (): JSX.Element => {
 		if (Global.shouldLogOnRender) console.log('ComponentRender (' + new Date().getSeconds() + ')');
 		var tags: JSX.Element[] = []
@@ -133,69 +141,87 @@ export class AppComponent extends React.Component<IProps, IState> {
 		// Get the right progress message...
 		var appMessage = app.getAppMessage();
 		tags.push(
-			<ExtraInfo key={'appMessage'} reminder={'Status'}>
+			<ExtraInfo key={'appMessageInfo'} reminder={app.error ? app.getDetailedAppMessage() : ''}>
 				<Tag key={'appMessage'}
 					id={app.uuid + appMessage}
 					icon={
 						app.getAppStatus() == Status.COMPLETED ? (
 							app.getAppMessage() == 'Closed' || app.getAppMessage() == 'Terminated' ? (
-								<ClearIcon sx={{
+								<Clear sx={{
 									height: '14px',
 									width: '14px',
-									fill: 'gray',
+									fill: Global.themeManager == undefined || Global.themeManager.isLight(Global.themeManager.theme) ? darken(Colors.CHIP_GREY, 0.35) : lighten(Colors.CHIP_GREY, 0.35),
 								}} />
 							) : (
-							(app.getError() ? (
-								<ClearIcon sx={{
+							(app.error ? (
+								<Clear sx={{
 									height: '14px',
 									width: '14px',
-									fill: '#ffffff',
+									fill: Global.themeManager == undefined || Global.themeManager.isLight(Global.themeManager.theme) ? darken(Colors.ERROR, 0.35) : lighten(Colors.ERROR, 0.35),
 								}} />
 							) : (
-								<CheckIcon sx={{
+								<Check sx={{
 									height: '14px',
 									width: '14px',
-									fill: '#ffffff',
+									fill: Global.themeManager == undefined || Global.themeManager.isLight(Global.themeManager.theme) ? darken(Colors.SUCCESS, 0.35) : lighten(Colors.SUCCESS, 0.35),
 								}} />
 							))
 						)) : undefined}
 					label={appMessage}
-					color={(this.props.app.getShowLoading() || app.getAppStatus() == Status.COMPLETED) ? this.getStatusColor() : undefined}
-					solid={app.getAppStatus() == Status.COMPLETED && (app.getAppMessage() != 'Closed' && app.getAppMessage() != 'Terminated')}
-					showLoading={this.props.app.getShowLoading()}
+					color={this.getChipColor()}
+					showLoading={app.getShowLoading()}
 					percentLoaded={undefined}
 				/>
 			</ExtraInfo>
 		)
+		if (app.warning) {
+			tags.push(
+				<ExtraInfo key={'appWarningInfo'} reminder={app.getAppWarningMessage()}>
+					<Tag key={'appWarning'}
+						icon={
+							<WarningRounded sx={{
+								height: '14px',
+								width: '14px',
+								fill: Global.themeManager == undefined || Global.themeManager.isLight(Global.themeManager.theme) ? darken(Colors.WARNING, 0.35) : lighten(Colors.WARNING, 0.35),
+							}} />
+						}
+						label={'Warning'}
+						color={Colors.WARNING}
+					/>
+				</ExtraInfo>
+			);
+		}
+
         var appElapsed = app.getTimeElapsed();
 		tags.push(
-			<ExtraInfo key={'appElapsed'} reminder='Duration'>
-				<Tag key={'appElapsed'} label={appElapsed} />
-			</ExtraInfo>
+			<Tag
+				key={'appElapsed'}
+				label={appElapsed}
+			/>
 		)
-		var appCost = app.getCost();
-		if (appCost) {
-			tags.push(
-				<ExtraInfo key={'appCost'} reminder='Approximate machine cost'>
-					<Tag key={'appCost'} label={appCost} />
-				</ExtraInfo>
-			)
-		}
-        return <>
-            <StatusWrapper key={this.props.app.uuid} statusColor={app.getAppStatus() == Status.COMPLETED ? 'var(--jp-layout-color2)' : this.getStatusColor()} opened={this.state.opened}>
+		// var appCost = app.getCost();
+		// if (appCost) {
+		// 	tags.push(
+		// 		<ExtraInfo key={'appCost'} reminder='Approximate machine cost'>
+		// 			<Tag key={'appCost'} label={appCost} />
+		// 		</ExtraInfo>
+		// 	)
+		// }
+        return (
+            <StatusWrapper key={app.uuid} statusColor={app.getAppStatus() == Status.COMPLETED ? 'var(--jp-layout-color2)' : this.getStatusColor()} opened={this.state.opened}>
                 <InfoSkirt
                     leftButton={
                         <ExtraInfo reminder='See details'>
-                            {this.props.app.getPopupComponent(() => this.safeSetState({ opened: true }), () => this.safeSetState({ opened: false }), this.props.openUserDialogTo)}
+                            {app.getPopupComponent(() => this.safeSetState({ opened: true }), () => this.safeSetState({ opened: false }))}
                         </ExtraInfo>
                     }
-                    rightButton={(this.props.app.preparing.completed && !this.props.app.preparing.error) && !this.props.app.running.completed ? (
+                    rightButton={(app.preparing.completed && !app.preparing.error) && !app.running.completed ? (
                         <>
                             <WarningPopup
                                 open={this.state.showStopJobPopup}
                                 headerText="Are you sure?"
                                 bodyText={(() => {
-                                    if (this.props.app.interactive) {
+                                    if (app.interactive) {
                                         return "This session is active. If you close it, the session cannot be resumed."
                                     } else {
                                         return "This job is running. If you terminate it, the job cannot be resumed."
@@ -211,7 +237,7 @@ export class AppComponent extends React.Component<IProps, IState> {
                                 }}
                                 continue={{
                                     text: (() => {
-                                        if (this.props.app.interactive) {
+                                        if (app.interactive) {
                                             return "Close it"
                                         } else {
                                             return "Terminate it"
@@ -243,8 +269,8 @@ export class AppComponent extends React.Component<IProps, IState> {
                                     padding: '3px',
                                 }}
                             >
-                                <ExtraInfo reminder={this.props.app.interactive ? 'Stop' : 'Terminate'}>
-                                    <StopIcon sx={{
+                                <ExtraInfo reminder={app.interactive ? 'Stop' : 'Terminate'}>
+                                    <Stop sx={{
                                         position: 'relative',
                                         width: '30px',
                                         height: '30px',
@@ -260,10 +286,10 @@ export class AppComponent extends React.Component<IProps, IState> {
                                 open={this.state.showDeleteJobPopup}
                                 headerText="Are you sure?"
                                 bodyText={(() => {
-                                    if (this.props.app.interactive) {
-                                        return "You will lose all session information and any files that have not been downloaded. This cannot be undone."
+                                    if (app.interactive) {
+                                        return "You will lose all session information and output files that have not been downloaded. This cannot be undone."
                                     } else {
-                                        return "You will lose all job information and any files that have not been downloaded. This cannot be undone."
+                                        return "You will lose all job information and output files that have not been downloaded. This cannot be undone."
                                     }
                                 })()}
                                 preventText="Don't ask me again"
@@ -287,9 +313,9 @@ export class AppComponent extends React.Component<IProps, IState> {
                             <ExtraInfo reminder='Delete'>
                                 <IconButton
                                     size='large'
-                                    disabled={this.state.waiting || !this.props.app.initializing.completed}
+                                    disabled={this.state.waiting || !app.initializing.completed}
                                     onClick={() => {
-                                        if (this.getDeleteJobPreventValue() || !this.props.app.running.started) {
+                                        if (this.getDeleteJobPreventValue() || !app.running.started) {
                                             this.handleDeleteClicked()
                                         } else {
                                             this.safeSetState({ showDeleteJobPopup: true })
@@ -297,7 +323,7 @@ export class AppComponent extends React.Component<IProps, IState> {
                                     }}
                                     sx={{position: 'relative', display: 'inline-block', width: '36px', height: '36px', padding: '3px'}}
                                 >
-                                    <DeleteIcon sx={{position: 'relative', width: '30px', height: '30px', padding: '3px'}} />
+                                    <Delete sx={{position: 'relative', width: '30px', height: '30px', padding: '3px'}} />
                                     {this.state.waiting && this.state.spinning && <CircularProgress size='30px' sx={{position: 'absolute', left: '3px', top: '3px'}} />}
                                 </IconButton>
                             </ExtraInfo>
@@ -305,10 +331,10 @@ export class AppComponent extends React.Component<IProps, IState> {
                     )}
                     tags={tags}
                 >
-                    {this.props.app.getIdentityComponent()}
+                    {app.getIdentityComponent()}
                 </InfoSkirt>
             </StatusWrapper>
-        </>;
+        )
 	}
 
 	public shouldComponentUpdate = (nextProps: IProps, nextState: IState): boolean => {
@@ -344,13 +370,35 @@ export class AppComponent extends React.Component<IProps, IState> {
 		}
 	}
 
+	private handleThemeChange = () => {
+        this.forceUpdate()
+    }
+
+	private handleAppChange = () => {
+		this.forceUpdate()
+	}
+
+	private handleRefreshWhileRunning = () => {
+		if (this.props.app.getAppStatus() !== Status.COMPLETED) {
+			this.forceUpdate()
+		}
+	}
+
+	private forceUpdateIntervalId: NodeJS.Timeout
+
 	// Will be called automatically when the component is mounted
 	public componentDidMount = () => {
         this._isMounted = true;
+		Global.themeManager.themeChanged.connect(this.handleThemeChange)
+		this.props.app.changed.connect(this.handleAppChange)
+		this.forceUpdateIntervalId = setInterval(() => this.handleRefreshWhileRunning(), 500)
 	}
 
 	// Will be called automatically when the component is unmounted
 	public componentWillUnmount = () => {
 		this._isMounted = false;
+		Global.themeManager.themeChanged.disconnect(this.handleThemeChange)
+		this.props.app.changed.disconnect(this.handleAppChange)
+		clearInterval(this.forceUpdateIntervalId)
 	}
 }
