@@ -21,11 +21,12 @@ import { ShadowedDivider } from '../../core';
 import Notebook from '../../core/notebook/Notebook';
 import FileServerUtils from '../../utils/FileServerUtils';
 import { NotificationContent } from '../../core/NotificationContent';
-import { OptumiConfig } from '../OptumiConfig';
+import { OptumiConfig, ProgramType } from '../OptumiConfig';
 import { ResourceGraph } from '../../core/ResourceGraph';
 import { Colors } from '../../Colors';
 import { Snackbar } from '../Snackbar';
 import ExtraInfo from '../../utils/ExtraInfo';
+import Script from '../../core/notebook/Script';
 
 const StyledDialog = withStyles({
     paper: {
@@ -39,7 +40,7 @@ const StyledDialog = withStyles({
 const enum Page {
     SUMMARY = 0,
     NOTIFICATIONS = 1,
-    NOTEBOOK = 2,
+    PROGRAM = 2,
     FILES = 3,
     MACHINE = 4,
     LOG = 5,
@@ -98,7 +99,9 @@ export class PopupAppComponent extends React.Component<IProps, IState> {
 
     private openAsNewNotebook = async () => {
         const app = this.props.app;
-        var path = app.path.replace('.ipynb', '-' + (app.annotationOrRunNum.replace(/\W/g, '')) + '.ipynb');
+        const fixedPth = Global.convertOptumiPathToJupyterPath(app.path)
+        const extension = fixedPth.split('.').pop()
+        var path = fixedPth.replace('.' + extension, '-' + (app.annotationOrRunNum.replace(/\W/g, '')) + '.' + extension);
         
         var inc = 0;
         var newPath = path;
@@ -107,8 +110,8 @@ export class PopupAppComponent extends React.Component<IProps, IState> {
             newPath = inc == 0 ? path : path.replace('.', '(' + inc + ').');
         }
 
-        var notebook: any = app.notebook;
-        FileServerUtils.saveNotebook(newPath, notebook).then((success: boolean) => { Global.docManager.open(newPath) });
+        var program: any = app.program;
+        FileServerUtils.saveNotebook(newPath, program).then((success: boolean) => { Global.docManager.open(newPath) });
         
         // Close the dialog
         this.handleClose();
@@ -244,15 +247,15 @@ export class PopupAppComponent extends React.Component<IProps, IState> {
                                         }}
                                         value={Page.NOTIFICATIONS}
                                     />}
-                                    {!app.interactive && <Tab
+                                    {!app.interactive && app.programType != ProgramType.UNKNOWN && <Tab
                                         disableRipple
-                                        label='Notebook'
+                                        label={app.programType == ProgramType.PYTHON_NOTEBOOK ? 'Notebook' : 'Script'}
                                         sx={{
                                             padding: '0px',
                                             minWidth: 'auto',
                                             minHeight: '36px',
                                         }}
-                                        value={Page.NOTEBOOK}
+                                        value={Page.PROGRAM}
                                     />}
                                     <Tab
                                         disableRipple
@@ -384,10 +387,16 @@ export class PopupAppComponent extends React.Component<IProps, IState> {
                                         handleClose={this.handleClose}
                                     />
                                 </DIV>
-                            ) : this.state.selectedPanel == Page.NOTEBOOK ? (
-                                <DIV sx={{overflow: 'auto', width: '100%', height: '100%'}}>
-                                    <Notebook notebook={app.notebook} />
-                                </DIV>
+                            ) : this.state.selectedPanel == Page.PROGRAM ? (
+                                (app.programType == ProgramType.PYTHON_NOTEBOOK ? (
+                                    <DIV sx={{overflow: 'auto', width: '100%', height: '100%'}}>
+                                        <Notebook notebook={app.program} />
+                                    </DIV>
+                                ) : (
+                                    <DIV sx={{overflow: 'auto', width: '100%', height: '100%'}}>
+                                        <Script source={app.program} mode='python' renderInColor={app.program.length / 5 < 2500} />
+                                    </DIV>
+                                ))
                             ) : this.state.selectedPanel == Page.FILES ? (
                                 <DIV sx={{padding: '8px'}}>
                                     {app.interactive && app.getAppStatus() != Status.COMPLETED ? (
@@ -419,11 +428,11 @@ export class PopupAppComponent extends React.Component<IProps, IState> {
                                         autoScroll={true}
                                     />
                                     {app.modules[0].output.length > 0 && (
-                                        <ExtraInfo reminder={'Download to ~/' + app.path.replace('.ipynb', '-' + (app.annotationOrRunNum.replace(/\W/g, '')) + '.log')}>
+                                        <ExtraInfo reminder={'Download to ~/' + app.path.replace(app.path.split('.').pop(), '-' + (app.annotationOrRunNum.replace(/\W/g, '')) + '.log')}>
                                             <Button
                                                 sx={{margin: '12px'}}
                                                 onClick={async () => {
-                                                    var path = app.path.replace('.ipynb', '-' + (app.annotationOrRunNum.replace(/\W/g, '')) + '.log');
+                                                    var path = app.path.replace(app.path.split('.').pop(), '-' + (app.annotationOrRunNum.replace(/\W/g, '')) + '.log');
                                                     var inc = 0;
 
                                                     var newPath = path;
