@@ -12,7 +12,6 @@ import FormatUtils from '../../utils/FormatUtils';
 import { IdentityMachineComponent } from './IdentityMachineComponent';
 import { MachineComponent } from './MachineComponent';
 import { MachinePreviewComponent } from './MachinePreviewComponent';
-import { PopupMachineComponent } from './PopupMachineComponent';
 
 export class Machine {
     computeCores: number[] = [0, 0, 0]
@@ -70,10 +69,6 @@ export class Machine {
         return React.createElement(IdentityMachineComponent, {key: this.uuid, machine: this});
     }
 
-    public getPopupComponent(): React.CElement<any, PopupMachineComponent> {
-        return React.createElement(PopupMachineComponent, {key: this.uuid, machine: this});
-    }
-
     public getStateMessage(): string {
         switch (this.state) {
             case 'requisition requested':
