@@ -149,11 +149,8 @@ export default /*React.memo(*/function ExtraInfo(props: ExtraInfoProps) {
                 </StyledPopover>
             )}
         >
-            {({ref, ...triggerHandler}) => {
-                // If you can't see triggerHandler.onBlur(args), expose it in OverlayInjectedProps in node_modules/react-bootstrap/esm/OverlayTrigger.d.ts
-                triggerHandler.onFocus
-                triggerHandler.onBlur // Duplicate onFocus for onBlur: !!! CONTROL CLICK THIS FOR QUICK NAVIGATION TO THE FILE !!! => node_modules/react-bootstrap/esm/OverlayTrigger.d.ts:10:5
-                return React.cloneElement(
+            {({ref, ...triggerHandler}) => (
+                React.cloneElement(
                     children,
                     Object.assign({
                         ref: ref,
@@ -161,7 +158,7 @@ export default /*React.memo(*/function ExtraInfo(props: ExtraInfoProps) {
                         onMouseOut: (...args: any[]) => handleMouseOut(triggerHandler, args), 
                     }, {...other})
                 )
-            }}
+            )}
         </OverlayTrigger>
     )
 }/*, (props: ExtraInfoProps, nextProps: ExtraInfoProps) => {
